@@ -311,26 +311,35 @@ LRT_nongaussian <- function(formula, data, grname, mod, link, family){
         # function for the reduced model in permut and LRT tests
         mod_fun <- ifelse(length(randterms) == 1, stats::glm, lme4::glmer)
         
+       
+        
+        ## likelihood-ratio-test
         LRT_mod <- as.numeric(stats::logLik(mod))
+        ## If the reduced model does not have random effects anymore, the LRT for the full
+        ## model must be fitted with ML instead of REML
+        ## LRT_mod <- ifelse(length(randterms) == 1, as.numeric(stats::logLik(stats::update(mod, REML=FALSE))), as.numeric(stats::logLik(mod)))
+        
         
         # calculate df for random slopes
         VarComps <- lme4::VarCorr(mod)
         mat_dims <- unlist(lapply(VarComps[grname], ncol))
-        calc_df <- function(k){
+        calc_df <- function(k, k_names){
                 if (k == 1) df <- 1
                 if (k > 1){
                         terms <- attr(terms(formula), "term.labels")
-                        current_term <- terms[grep(names(k), terms)]
-                        if (grep("0", current_term)){
-                                df <- (k*(k-1)/2+k) - 1    
-                        } else {
+                        current_term <- terms[grep(k_names, terms)]
+                        # the 0 case is just necessary when we allow fitting random intercepts
+                        # and random slopes seperately without estimating correlations.
+                        #if (regexpr("0", current_term)>0){
+                        #        df <- (k*(k-1)/2+k) - 1    
+                        #} else {
                                 df <- k*(k-1)/2+k  
-                        }
+                        #}
                 } 
                 df
         }
-        LRT_df <- sapply(mat_dims, calc_df) 
-
+        LRT_df <- mapply(calc_df, mat_dims, names(mat_dims)) 
+        
         for (i in c("LRT_P", "LRT_D", "LRT_red")) assign(i, rep(NA, length(grname)))
 
         for (i in 1:length(grname)) {
@@ -344,9 +353,9 @@ LRT_nongaussian <- function(formula, data, grname, mod, link, family){
                 LRT_P[i] <- ifelse(LRT_D[i] <= 0, 1, stats::pchisq(LRT_D[i], LRT_df[i], lower.tail = FALSE)) 
         }
         
-        # division by 2 if LRT_df = 1
-        LRT_P <- LRT_P/ifelse(LRT_df==1,2,1)
-        
+        # division by 2 if LRT_df = 1 and LRT_D > 0
+        LRT_P <- LRT_P/ifelse(LRT_df==1 & LRT_D > 0,2,1)
+
         LRT_table <- data.frame(logL_red = LRT_red, LR_D = LRT_D, LRT_P = LRT_P, LRT_df =  LRT_df, stringsAsFactors = FALSE)
         row.names(LRT_table) <- grname
         
